<h3 align="center">
	<img src="https://github.com/user-attachments/assets/63234655-e60b-496e-bf0d-b5b059b79a66" width="100" alt="Logo"/><br/>
	<a href="https://github.com/transistxr/colorpycker">Colorpycker</a>
</h3>

<p align=center>
  <a>A system-wide color picker written in Qt inspired by <a href="https://learn.microsoft.com/en-us/windows/powertoys/color-picker">PowerToys Color Picker</a></a>.
</p>

![colorpycker](https://github.com/user-attachments/assets/9274635f-1897-4d65-83b0-0a28a7c40d19)


**Note: Currently only works on X11 systems**

# Installation

```
pip install colorpycker
```
